@@ -20,14 +20,14 @@ import os
 class AudioFileAdmin(admin.ModelAdmin):
     """Allows the administrator to view and modify uploaded audio files"""
 
-    list_display = ('id', 'name', 'audio_file_player', 'created_date', 'user')
-    #list_display_links = ['id', 'name',]
+    list_display = ('id', 'name', 'tag', 'audio_file_player', 'created_date', 'user')
+    # list_display_links = ['id', 'name',]
     ordering = ('id', )
 
     actions = ['custom_delete_selected']
 
     def custom_delete_selected(self, request, queryset):
-        #custom delete code
+        # custom delete code
         n = queryset.count()
         for i in queryset:
             if i.audio_file:
@@ -42,4 +42,5 @@ class AudioFileAdmin(admin.ModelAdmin):
         del actions['delete_selected']
         return actions
 
+
 admin.site.register(AudioFile, AudioFileAdmin)
