@@ -25,5 +25,19 @@ class ThreadLocals(object):
     Middleware that gets various objects from the
     request object and saves them in thread local storage.
     """
+
+    def __init__(self, get_response=None):
+        self.get_response = get_response
+
+    def __call__(self, request):
+        response = None
+        if hasattr(self, 'process_request'):
+            response = self.process_request(request)
+        if not response:
+            response = self.get_response(request)
+        if hasattr(self, 'process_response'):
+            response = self.process_response(request, response)
+        return response
+
     def process_request(self, request):
         _thread_locals.request = request
